@@ -1,8 +1,10 @@
-from twitterhal.command_line import CommandLine
 from twitterhal.conf import settings
 from twitterhal.engine import TwitterHAL
 from twitterhal.gracefulkiller import killer
 from twitterhal.runtime import runner
 
 
-__all__ = ["TwitterHAL", "CommandLine", "settings", "killer", "runner"]
+__version__ = "0.4.4"
+VERSION = tuple(map(int, __version__.split(".")))
+
+__all__ = ["TwitterHAL", "settings", "killer", "runner", "__version__", "VERSION"]
